%global         so_version   0

Name:           jsonnet
Version:        0.17.0
Release:        1%{?dist}
Summary:        Diff JSON and JSON-like structures

# The bundled MD5 library is RSA licenced
License:        ASL 2.0 and RSA

URL:            https://github.com/google/jsonnet
Source0:        %{url}/archive/v%{version}/%{name}-%{version}.tar.gz

# Upstream wants to build single source wheels
# these benefit from static linking,
# but we want to link to libjsonnet here so we are sharing the lib
Patch0001:      0001-Dynamic-link-to-libjsonnet-rather-than-static.patch
Patch0002:      0002-jsonnet-0.17.0-do-not-override-compiler-flags.patch


# Bundled MD5 C++ class with very permissive license (RSA)
# rpmlint must be notified of the unversioned provides
Provides:       bundled(md5-thilo)

BuildRequires:  python3-devel
BuildRequires:  python3-setuptools

BuildRequires:  bash cmake gcc gcc-c++ gtest-devel make

# json is header only, so note the static lib for tracking
BuildRequires:  json-devel json-static

# Set our toplevel runtime requirements
Requires:       %{name}-libs%{?_isa} = %{version}-%{release}

%global _description %{expand:
A data templating language for app and tool developers based on JSON}

%description %{_description}


%package -n python3-%{name}
Summary:        %{name} Bindings for Python
Requires:       %{name}-libs%{?_isa} = %{version}-%{release}

%description -n python3-%{name} %{_description}


%package libs
Summary:        Shared Libraries for %{name}

%description libs %{_description}


%package devel
Summary:        Development Headers for %{name}
Requires:       %{name}-libs%{?_isa} = %{version}-%{release}

%description devel %{_description}


%package doc
Summary:        Documentation for %{name}
License:        CC-BY
BuildArch:      noarch

%description doc %{_description}


%prep
%autosetup

# use system json lib instead
rm -rfv third_party/json/*

# don't bundel rapidyaml
rm -rfv third_party/rapidyaml/*

# don't bundle thirdparty doc resources
# this leaves the doc "unbuilt" but still sorta useful
rm -rf doc/third_party
rm -rf doc/.gitignore


%build

%if 0%{?rhel} == 8
# required macro drop for EL8
%undefine __cmake_in_source_build
%endif


# FIXME:
# For reasons I'm not following, json-devel isn't added to include by cmake
#
# explicitly set -fPIC so python can pick it up later on
export CXXFLAGS="%{optflags} -fPIC -I%{_includedir}/nlohmann"

# setup our build environment
%cmake -DBUILD_SHARED_BINARIES:BOOL=ON -DBUILD_STATIC_LIBS:BOOL=OFF -DUSE_SYSTEM_JSON:BOOL=ON -DUSE_SYSTEM_GTEST:BOOL=ON

# make tools and headers
%cmake_build

# make python binding
%{py3_build}


%install
%{cmake_install}

# install python binding
%{py3_install}


%check
%ctest


%files
%{_bindir}/jsonnet
%{_bindir}/jsonnetfmt

%files libs
%license LICENSE
%doc README.md
%{_libdir}/lib%{name}*.so.%{so_version}
%{_libdir}/lib%{name}*.so.%{version}

%files devel
%{_includedir}/lib%{name}*
%{_libdir}/lib%{name}*.so

%files -n python3-%{name}
# rpmlint must be notified this is not versioned on purpose
%{python3_sitearch}/_%{name}*.so
%{python3_sitearch}/%{name}-%{version}-py%{python3_version}.egg-info

%files doc
%license LICENSE
%doc README.md
%doc CONTRIBUTING
%doc doc
%doc examples
# don't package up the self-check script
%exclude %{_docdir}/%{name}-doc/examples/*.sh


%changelog
* Thu Jun 17 2021 Pat Riehecky <riehecky@fnal.gov> - 0.17.0-1
- Initial package.
